==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/Output/alsa/translations/alsa_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="cs">
<defaultcodec></defaultcodec>
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="31"/>
        <source>ALSA Plugin</source>
        <translation>Modul ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="50"/>
        <source>About ALSA Output Plugin</source>
        <translation>O modulu ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="51"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation>Výstupní modul Qmmp ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>ALSA Plugin Settings</source>
        <translation>Nastavení pluginu ALSA</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Device Settings</source>
        <translation>Nastavení zařízení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Audio device</source>
        <translation>Zvukové zařízení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Mixer</source>
        <translation>Mixér</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="106"/>
        <source>Mixer card:</source>
        <translation>Zvuková karta:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Mixer device:</source>
        <translation>Ovládání hlasitosti:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="133"/>
        <source>Advanced Settings</source>
        <translation>Pokročilá nastavení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="154"/>
        <source>Soundcard</source>
        <translation>Zvuková karta</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="160"/>
        <source>Buffer time (ms):</source>
        <translation>Velikost bufferu (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="196"/>
        <source>Period time (ms):</source>
        <translation>Délka periody (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="272"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="279"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="232"/>
        <source>Use mmap access</source>
        <translation>Použít mmap</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/Output/alsa/translations/alsa_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="31"/>
        <source>ALSA Plugin</source>
        <translation>Modul ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="56"/>
        <source>About ALSA Output Plugin</source>
        <translation>O modulu ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="57"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation>Výstupní modul Qmmp ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="58"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ALSA Plugin Settings</source>
        <translation>Nastavení pluginu ALSA</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="24"/>
        <source>Device Settings</source>
        <translation>Nastavení zařízení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="36"/>
        <source>Audio device</source>
        <translation>Zvukové zařízení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Mixer</source>
        <translation>Mixér</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Mixer card:</source>
        <translation>Zvuková karta:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="73"/>
        <source>Mixer device:</source>
        <translation>Ovládání hlasitosti:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>Advanced Settings</source>
        <translation>Pokročilá nastavení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="102"/>
        <source>Soundcard</source>
        <translation>Zvuková karta</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="108"/>
        <source>Buffer time (ms):</source>
        <translation>Velikost bufferu (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="144"/>
        <source>Period time (ms):</source>
        <translation>Délka periody (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="180"/>
        <source>Use mmap access</source>
        <translation>Použít mmap</translation>
    </message>
</context>
</TS>
